# Configuring KPIs
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configuring-kpis#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-kpis#prerequisites)
  * [Creating a Custom KPI](https://help.sap.com/docs/leanix/ea/configuring-kpis#creating-a-custom-kpi)
  * [Calculation Methods](https://help.sap.com/docs/leanix/ea/configuring-kpis#calculation-methods)
  * [Aggregation Options](https://help.sap.com/docs/leanix/ea/configuring-kpis#aggregation-options)
  * [Inventory Filters](https://help.sap.com/docs/leanix/ea/configuring-kpis#inventory-filters)
  * [Examples](https://help.sap.com/docs/leanix/ea/configuring-kpis#examples)


Learn how to configure KPIs and explore the concepts behind each configuration setting.
